==> qcake_0.6.3.orig.tar.gz: qcake-0.6.3/src/barrier.hpp <==
/***************************************************************************
                          barrier.hpp  -  description
                             -------------------
    begin                : Mit Sep 25 13:11:41 CEST 2002
    copyright            : (C) 2007 by Harald Krippel
    email                : harald@the-develop.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef BARRIER_H
#define BARRIER_H

/**
  *@author Krippel Harald
  */


#include <plib/ssg.h>
#include <ode/ode.h>


class Barrier
{
   public:
     Barrier(void);

     void   createOdeBody(dSpaceID odspace);
     void   update();
     void   setTransform (ssgTransform *objtrans, const dReal pos[3], const dReal R[12],dVector3 dxyz);
     void   setPosition ();
     void   setObjtrans (ssgTransform *trans);     
     void   getPosition ( sgCoord  *bodypos );
     void   setRotation (float h, float p, float r);
     ~Barrier(void);

   ssgTransform *boxobjtrans;   
   ssgTransform *objtrans;
   /* plib */
   sgCoord      pos;
   /* ode */
   dGeomID odbox;
  
protected:
};

#endif

==> qcake_0.7.2.orig.tar.gz: qcake-0.7.2/src/barrier.hpp <==
/***************************************************************************
                          barrier.hpp  -  description
                             -------------------
    begin                : Mit Sep 25 13:11:41 CEST 2002
    copyright            : (C) 2007 by Harald Krippel
    email                : harald@the-develop.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef BARRIER_H
#define BARRIER_H

/**
  *@author Krippel Harald
  */

#include <QObject>
#include <plib/ssg.h>
#include <ode/ode.h>

/*!

 This Class is the glue between ODE barriers and QCake.

*/

class Barrier: public QObject
{
   Q_OBJECT 
   public:
     Barrier(QObject *parent=0);

     void   createOdeBody(dSpaceID odspace);
     void   setTransform (ssgTransform *objtrans, const dReal pos[3], const dReal R[12],dVector3 dxyz);
     void   setPosition ();
     void   setObjtrans (ssgTransform *trans);     
     void   getPosition ( sgCoord  *bodypos );
     void   setRotation (float h, float p, float r);
     ~Barrier(void);

   ssgTransform *boxobjtrans;   
   ssgTransform *objtrans;
   /* plib */
   sgCoord      pos;
   /* ode */
   dGeomID odbox;
  public slots:
     void   update(float dt);

protected:
};

#endif
